==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_soapcastle_talaroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")RoomInit()FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")RoomInit()FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")RoomInit()FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")RoomInit()FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")RoomInit()FAI(4)
end

function RoomInit()
    if(FLJ("ExploreEscapeRoutes")) then
        ANP("Computer1","no_link")
        ANP("Teleporter1","empty")
    end
end

function GoSoapCastle()
    PRI()FAO(3)TRA("CS_soapcastle","E0091",33,30)
end

function SwimSoapCastleJail()
    PRI()FAO(2)TRA("CS_soapcastle_jail","E0090",38,1)
end

function SwimSoapCastleStoreRoom()
    PRI()FAO(0)TRA("CS_soapcastle_storeroom","E0092",38,21)
end

function Computer1()
    if(FLJ("ExploreEscapeRoutes")) then
        PRI()
        MS4("\n屏幕上显示着：")NOD()CLR()
        TUR()CAT("\n[没有可传送的目的地。]")NOD()
    else
        PRI()
        MS4("看这个体型")
        CAT("\n应该是巨人使用的电脑了吧。")NOD()CLR()
        FAC("jack_normal")CAT("\n我想也是...")NOD()
    end
end

function SetTeleporter()
    if(FLJ("ExploreEscapeRoutes")) then
        PRI()
        MS4("\n传送器正处于待机状态。")NOD()
    else
        PRI()
        MS4("这是一个大型传送器，")NOD()
        CAT("\n目前没有开机。")NOD()
    end
end

function DryIronhead()
    KEY()
    SNP("CS_soapwalker_animate",23,15,1,"mainLayer","Tala1")
    ANP("Tala1","back")
    ANP("Computer1","special")
    ANP("Teleporter1","special")
    SNP("CS_redhead_animate",30,12,0,"mainLayer","Ironhead1")
    FAI(2)
    WAI(32)
    FAC("soapwalker_normal")MS3("这样应该就行了，")NOD()
    ANP("Tala1","normal")
    CAT("\n快点给我变干吧~")NOD()CLR()
    CAT("\n虽然有可能会变成烤鱼就是了...")NOD()CLO()
    FAO(0)
    TRA("CS_soapcastle_waterfall","SoapKingGoResturant",3,17)
end

==> ocstore25_6_20.zip: OcStore/Prgm/data/map/CS_soapcastle_talaroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")RoomInit()FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")RoomInit()FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")RoomInit()FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")RoomInit()FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")RoomInit()FAI(4)
end

function RoomInit()
    if(FLJ("HeroBack")) then
        ANP("Computer1","linked")
        ANP("Teleporter1","on")
    elseif(FLJ("ExploreEscapeRoutes")) then
        ANP("Computer1","no_link")
        ANP("Teleporter1","empty")
    end
end

function GoSoapCastle()
    PRI()FAO(3)TRA("CS_soapcastle","E0091",33,30)
end

function SwimSoapCastleJail()
    PRI()FAO(2)TRA("CS_soapcastle_jail","E0090",38,1)
end

function SwimSoapCastleStoreRoom()
    PRI()FAO(0)TRA("CS_soapcastle_storeroom","E0092",38,21)
end

function Computer1()
    if(FLJ("HeroBack")) then
        PRI()
        MS4("\n屏幕上显示着：")NOD()CLR()
        TUR()CAT("\n[已经连接到黑市。]")NOD()
    elseif(FLJ("ExploreEscapeRoutes")) then
        PRI()
        MS4("\n屏幕上显示着：")NOD()CLR()
        TUR()CAT("\n[没有可传送的目的地。]")NOD()
    else
        PRI()
        MS4("看这个体型")
        CAT("\n应该是巨人使用的电脑了吧。")NOD()CLR()
        FAC("jack_normal")CAT("\n我想也是...")NOD()
    end
end

function SetTeleporter()
    if(FLJ("HeroBack")) then
        PRI()
        MS4("\n是否传送到[黑市]？")YNJ()
        if(YES()) then
            CLO()
            KEY()
            AMC("normal")
            WAI(60)
            SOU("CS_029_teleport")
            ANP("TeleporterBase1","light_on")
            AMC("teleport_out")
            WAI(100)
            FAO(0)
            --TRA("CS_gaudi_blackmaket_teleport","QuoteCurlyArrive",10,14)
            TRA("CS_gaudi_blackmaket","TheTrade",16,19)
        end
    elseif(FLJ("ExploreEscapeRoutes")) then
        PRI()
        MS4("\n传送器正处于待机状态。")NOD()
    else
        PRI()
        MS4("这是一个大型传送器，")NOD()
        CAT("\n目前没有开机。")NOD()
    end
end

function DryIronhead()
    KEY()
    SNP("CS_soapwalker_animate",23,15,1,"mainLayer","Tala1")
    ANP("Tala1","back")
    ANP("Computer1","special")
    ANP("Teleporter1","special")
    SNP("CS_redhead_animate",30,12,0,"mainLayer","Ironhead1")
    FAI(2)
    WAI(32)
    FAC("soapwalker_normal")MS3("这样应该就行了，")NOD()
    ANP("Tala1","normal")
    CAT("\n快点给我变干吧~")NOD()CLR()
    CAT("\n虽然有可能会变成烤鱼就是了...")NOD()CLO()
    FAO(0)
    TRA("CS_soapcastle_waterfall","SoapKingGoResturant",3,17)
end
